<?php

namespace Drupal\Tests\oidc\Unit;

use Drupal\externalauth\Event\ExternalAuthLoginEvent;
use Drupal\oidc\EventSubscriber\ExternalAuthEventSubscriber;
use Drupal\oidc\JsonWebTokens;
use Drupal\oidc\OpenidConnectSessionInterface;
use Drupal\Tests\UnitTestCase;
use Drupal\user\UserInterface;
use Prophecy\Argument;

/**
 * Tests the ExternalAuthEventSubscriber class.
 *
 * @covers \Drupal\oidc\EventSubscriber\ExternalAuthEventSubscriber
 */
class ExternalAuthEventSubscriberTest extends UnitTestCase {

  /**
   * Tests the onLogin() method.
   *
   * @covers \Drupal\oidc\EventSubscriber\ExternalAuthEventSubscriber::onLogin
   */
  function testOnLogin() {
    $tokens = $this->prophesize(JsonWebTokens::class);
    $tokens->getUsername()->willReturn('john.doe');
    $tokens->getEmail()->willReturn('john.doe@example.com');
    $tokens->getGivenName()->willReturn('John');
    $tokens->getFamilyName()->willReturn('Doe');

    $session = $this->prophesize(OpenidConnectSessionInterface::class);
    $session->getJsonWebTokens()->willReturn($tokens->reveal());

    $user = $this->prophesize(UserInterface::class);
    $user->getAccountName()->willReturn(NULL);
    $user->getEmail()->willReturn(NULL);
    $user->get(Argument::type('string'))->willReturn((object) ['value' => NULL]);
    $user->save()->willReturn(NULL);

    $user->setUsername(Argument::type('string'))->will(function ($args) use ($user) {
      $user->getAccountName()->willReturn($args[0]);
    });

    $user->setEmail(Argument::type('string'))->will(function ($args) use ($user) {
      $user->getEmail()->willReturn($args[0]);
    });

    $user->set(Argument::type('string'), Argument::any())->will(function ($args) use ($user) {
      $user->get($args[0])->willReturn((object) ['value' => $args[1]]);
    });

    $user = $user->reveal();

    $event = $this->prophesize(ExternalAuthLoginEvent::class);
    $event->getAccount()->willReturn($user);

    $external_auth_subscriber = new ExternalAuthEventSubscriber($session->reveal());
    $external_auth_subscriber->onLogin($event->reveal());

    self::assertEquals('john.doe', $user->getAccountName());
    self::assertEquals('john.doe@example.com', $user->getEmail());
    self::assertEquals('John', $user->get('given_name')->value);
    self::assertEquals('Doe', $user->get('family_name')->value);
  }

}
